Gimmicks and hacks to make some of my other modules more robust and less demanding of others.


*Latest release 20200418.1*:
Initial release with logging call stubs.

Gimmicks and hacks to make some of my other modules more robust and
less demanding of others.

## Function `debug(*a, **kw)`

# Wrapper for `debug()` which does a deferred import.

## Function `error(*a, **kw)`

# Wrapper for `error()` which does a deferred import.

## Function `exception(*a, **kw)`

# Wrapper for `exception()` which does a deferred import.

## Function `info(*a, **kw)`

# Wrapper for `info()` which does a deferred import.

## Function `log(*a, **kw)`

# Wrapper for `log()` which does a deferred import.

## Function `warning(*a, **kw)`

# Wrapper for `warning()` which does a deferred import.



# Release Log

*Release 20200418.1*:
Initial release with logging call stubs.
